translate.misc.progressbar

Package translate :: Package misc :: Module progressbar |
[hide private]
[frames] | no frames]

# Module progressbar

source code

progress bar utilities for reporting feedback on progress of application...

Classes | [hide private]
| DotsProgressBar an ultra-simple progress indicator that just writes a dot for each action
| NoProgressBar an invisible indicator that does nothing...
| ProgressBar a plain progress bar that doesn't know very much about output...
| MessageProgressBar a ProgressBar that just writes out the messages without any progress display
| HashProgressBar a ProgressBar which knows how to go back to the beginning of the line...
| VerboseProgressBar

Functions | [hide private]
test(progressbar) | source code